<h1 align="center">
  <a href="http://www.junhaowen.com/SOPNMF/">
    <img src="http://www.junhaowen.com/SOPNMF/images/sopnmf.png" alt="SOPNMF Logo" width="120" height="120">
  </a>
  <br/>
  SOPNMF
</h1>

<p align="center"><strong>Stochastic orthogonally projective non-negative matrix factorization</strong></p>

<p align="center">
  <a href="http://www.junhaowen.com/SOPNMF/">Documentation</a> |
  <a href="http://www.junhaowen.com/SOPNMF/">Paper</a>
</p>

## About the project
**SOPNMF** is the python implementation of the Matlab version of Orthogonal Projective Non-negative Matrix Factorization: [brainparts](https://github.com/asotiras/brainparts), and its stochastic extension.

> :warning: **The documentation of this software is currently under development**

## Citing this work
> Sotiras, A., Resnick, S.M. and Davatzikos, C., 2015. **Finding imaging patterns of structural covariance via non-negative matrix factorization**. Neuroimage, 108, pp.1-16. [doi:10.1016/j.neuroimage.2014.11.045](https://www.sciencedirect.com/science/article/pii/S1053811914009756?via%3Dihub)
> TBD

## Publications around SOPNMF
> Wen, J., Varol, E., Sotiras, A., Yang, Z., Chand, G.B., Erus, G., Shou, H., Abdulkadir, A., Hwang, G., Dwyer, D.B. and Pigoni, A., 2022. Multi-scale semi-supervised clustering of brain images: deriving disease subtypes. Medical Image Analysis, 75, p.102304. - [Link](https://scholar.google.com/citations?view_op=view_citation&hl=en&user=4Wq_FukAAAAJ&sortby=pubdate&citation_for_view=4Wq_FukAAAAJ:9ZlFYXVOiuMC)
